/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.bu;

import java.util.List;

import org.tinygroup.appconfig.AppConfig;
import org.tinygroup.bu.config.BusinessUnitInfo;
import org.tinygroup.bu.config.BusinessUnitProcessor;
import org.tinygroup.fileresolver.FileProcessor;
import org.tinygroup.vfs.FileObject;

/**
 * BU就是业务单元，它被放在业务单元目录中
 * 业务单元必须经过安装，才能生效
 * 业务单元可以通过卸载，从业务单元中删除，卸载时可以选择是否执行清理工作，如果执行清理，则执行其清理操作
 * BU组织结构
 * 根目录上必须存在BusinessUnit.xml文件，文件中放置BusinessUnitInfo说明
 * 如果有自己的安装与卸载器，则必须在根目录上存放文件BusinessUnitProcess.xml文件，文件中存放BusinessUnitProcessor序列化文件
 * 如果一个业务单元其它版本已经存在，则安装时，会使之被卸载，但是不执行其uninstall方法，系统认为新安装的包会知道怎么进行升级或降级
 */

/**
 * 业务单元管理器
 * @author luoguo
 *
 */
public interface BusinessUnitManager extends AppConfig{
	String BUMANAGER = "BuManager";
	String BUSINESS_UNIT_FILE="BusinessUnit.xml";
	
	String BUSINESS_UNIT_PROCESS_FILE="BusinessUnitProcess.xml";
	
	String BUSINESS_UNIT_MANAGER_BEAN_NAME="businessUnitManager";

	String XSTEAM_PACKAGE_NAME="bu";
	/**
	 * 返回businessUnit，如果出现异常，则说明不是业务单元就可以跳过了
	 * @param fileObject BU的jar文件
	 * @return
	 */
	BusinessUnitInfo getBusinessUnitInfo(FileObject fileObject);

	/**
	 * 添加一个业务单元
	 * @param fileObject
	 */
	void addBusinessUnit(FileObject fileObject);

	/**
	 * 返回BU信息列表
	 * @return
	 */
	List<BusinessUnitInfo> getBusinessUnitInfoList();

	/**
	 * 安装业务单元 ，执行安装处理器
	 * @param fileObject 业务单元所在的Jar
	 */
	void install(FileObject fileObject);
	
	/**
	 * 安装业务单元 ，执行安装处理器
	 */
	void install();

	/**
	 * 卸载业务单元，执行业务单元的卸载处理器
	 * @param fileObject
	 * @return
	 */
	void uninstall(FileObject fileObject);
	
	
	void uninstall(String packageName,String name,String version);

	/**
	 * 根据包名，BU名字，版本返回BU
	 * @param packageName
	 * @param name
	 * @param version
	 * @return
	 */
	BusinessUnitInfo getBusinessUnitInfo(String packageName, String name,
			String version);
	/**
	 * 
	 * @param businessUnitInfo
	 * @return
	 */
	FileObject getBusinessUnit(BusinessUnitInfo businessUnitInfo);
	/**
	 * 业务单元处理器
	 * @param businessUnitProcessor
	 */
	void addBusinessUnitProcessor(BusinessUnitProcessor businessUnitProcessor);
	
	//获取插件资源扫描器，主要提供给BU使用
	List<FileProcessor> getResourceProcessors();
	
	//获取插件资源扫描器，主要提供给BU使用
	List<FileProcessor> getResourceRemoveProcessors();
	
	void load(String path);
	
	
}
