/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.bu.config;

import java.util.ArrayList;
import java.util.List;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

/**
 * 业务描述单元
 * @author luoguo
 *
 */
@XStreamAlias("business-unit-info")
public class BusinessUnitInfo {
	@XStreamAsAttribute
	@XStreamAlias("package-name")
	private String packageName;
	@XStreamAsAttribute
	private String name;
	@XStreamAsAttribute
	private String version;
	@XStreamAsAttribute
	private String title;
	private String description;
	@XStreamAlias("jar-dependencies")
	private List<BusinessUnitJarDependency> businessUnitJarDependencies;
	@XStreamAlias("jar-extends")
	private List<BusinessUnitJarExtend> businessUnitJarExtends;
	@XStreamAlias("dependency-business-units")
	private List<DependencyBusinessUnit> dependencyBusinessUnits;

	public List<BusinessUnitJarDependency> getBusinessUnitJarDependencies() {
		if(businessUnitJarDependencies==null){
			businessUnitJarDependencies = new ArrayList<BusinessUnitJarDependency>();
		}
		return businessUnitJarDependencies;
	}

	public void setBusinessUnitJarDependencies(
			List<BusinessUnitJarDependency> businessUnitJarDependencies) {
		this.businessUnitJarDependencies = businessUnitJarDependencies;
	}

	public List<BusinessUnitJarExtend> getBusinessUnitJarExtends() {
		if( businessUnitJarExtends==null){
			 businessUnitJarExtends = new ArrayList<BusinessUnitJarExtend>();
		}
		return businessUnitJarExtends;
	}

	public void setBusinessUnitJarExtends(
			List<BusinessUnitJarExtend> businessUnitJarExtends) {
		this.businessUnitJarExtends = businessUnitJarExtends;
	}

	public List<DependencyBusinessUnit> getDependencyBusinessUnits() {
		//20130311 如果不存在依赖，那么创建一个空list
		if(dependencyBusinessUnits==null){
			dependencyBusinessUnits=new ArrayList<DependencyBusinessUnit>();
		}
		return dependencyBusinessUnits;
	}

	public void setDependencyBusinessUnits(
			List<DependencyBusinessUnit> dependencyBusinessUnits) {
		this.dependencyBusinessUnits = dependencyBusinessUnits;
	}

	public String getName() {
		return name;
	}

	public String getPackageName() {
		return packageName;
	}

	public void setPackageName(String packageName) {
		this.packageName = packageName;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

}
