/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.bu.fileresolver;

import org.tinygroup.bu.BusinessUnitManager;
import org.tinygroup.fileresolver.impl.AbstractFileProcessor;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.springutil.SpringUtil;
import org.tinygroup.vfs.FileObject;

/**
 * 查找所有jar且jar中存在业务单元文件
 * 
 * @author renhui
 * 
 */
public class BusinessUnitJarProcess extends AbstractFileProcessor {

	private static final String BUSINESS_UNIT_JAR = ".jar";

	public boolean isMatch(FileObject fileObject) {
		boolean isMatch = false;
		if (fileObject.getFileName().endsWith(BUSINESS_UNIT_JAR)) {
			isMatch = existBuFile(fileObject);
		}
		return isMatch;
	}

	private boolean existBuFile(FileObject fileObject) {
		boolean exist = false;
		FileObject bUnit = fileObject
				.getChild(BusinessUnitManager.BUSINESS_UNIT_FILE);
		if (bUnit != null) {
			exist = true;
		}
		return exist;
	}

	public void process() {

		BusinessUnitManager businessUnitManager = SpringUtil
				.getBean(BusinessUnitManager.BUSINESS_UNIT_MANAGER_BEAN_NAME);
		for (FileObject fileObject : fileObjects) {
			logger.logMessage(LogLevel.INFO, "正在加载业务单元[{0}]",
					fileObject.getAbsolutePath());
			businessUnitManager.addBusinessUnit(fileObject);
			logger.logMessage(LogLevel.INFO, "加载业务单元[{0}]结束",
					fileObject.getAbsolutePath());
		}

	}

}
