/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.bu.impl;

import java.lang.reflect.Method;
import java.net.URL;
import java.net.URLClassLoader;

import org.tinygroup.fileresolver.impl.FileResolverImpl;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.vfs.FileObject;

/**
 * 加载jar包中的类文件
 * 
 * @author renhui
 * 
 */
public final class ExtClasspathLoader {
	/** */
	/** URLClassLoader的addURL方法 */
	private static Method addURL = initAddMethod();

	private static URLClassLoader classloader = (URLClassLoader) ClassLoader
			.getSystemClassLoader();

	private static Logger logger = LoggerFactory
			.getLogger(FileResolverImpl.class);

	/** */
	/**
	 * 初始化addUrl 方法.
	 * 
	 * @return 可访问addUrl方法的Method对象
	 */
	private static Method initAddMethod() {
		try {
			Method add = URLClassLoader.class.getDeclaredMethod("addURL",
					new Class[] { URL.class });
			add.setAccessible(true);
			return add;
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}

	public static void loadClasspath(FileObject fileObject) {
			logger.logMessage(LogLevel.DEBUG, "classload开始加载文件：{}",
					fileObject.getAbsolutePath());
			loopFiles(fileObject);
			logger.logMessage(LogLevel.DEBUG, "classload加载文件：{}结束",
					fileObject.getAbsolutePath());

	}

	/** */
	/**
	 * 循环遍历目录，找出所有的jar包。
	 * 
	 * @param file
	 *            当前遍历文件
	 */
	private static void loopFiles(FileObject fileObject)
			 {
		if (fileObject.isFolder()) {
			for (FileObject tmp : fileObject.getChildren()) {
				loopFiles(tmp);
			}
		} else {
			String extName = fileObject.getExtName();
			
			if (extName!=null && (extName.endsWith("jar") || extName.endsWith("zip"))) {
				addURL(fileObject);
			}
		}
	}

	/**
	 * 通过filepath加载文件到classpath。
	 * 
	 * @param filePath
	 *            文件路径
	 * @return URL
	 * @throws Exception
	 *             异常
	 */
	private static void addURL(FileObject fileObject) {
		URL url = null;
		try {
			url = new URL(fileObject.getURL().toString());
			addURL.invoke(classloader, new Object[] { url });
		} catch (Exception e) {
			logger.errorMessage("添加URL:{}到classloader出错", e, url);
		}
	}

}