/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.bu.loader.impl;

import java.net.URL;
import java.util.List;

import org.tinygroup.bu.BusinessUnitManager;
import org.tinygroup.bu.BusinessUnitManagerFactory;
import org.tinygroup.fileresolver.FileProcessor;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.vfs.FileObject;
import org.tinygroup.vfs.VFS;

public class BuFileResolver {

	private static Logger logger = LoggerFactory
			.getLogger(BuFileResolver.class);

	public void deResolve(URL[] urls) {
		List<FileProcessor> resourceRemoveProcessorList = BusinessUnitManagerFactory
				.getManager().getResourceRemoveProcessors();
		process(urls, resourceRemoveProcessorList);
	}

	private void process(URL[] urls,
			List<FileProcessor> processors) {
		cleanProcessor(processors);
		for (URL url : urls) {
			resole(url, processors);
		}
		for (FileProcessor fileProcessor : processors) {
			fileProcessor.process();
		}
	}

	/**
	 * 
	 * @param urls
	 *            jar包的url地址列表
	 */
	public void resolve(URL[] urls) {
		BusinessUnitManager manager = BusinessUnitManagerFactory.getManager();
		List<FileProcessor> fileProcessorList = manager.getResourceProcessors();
		process(urls, fileProcessorList);
	}

	private void resole(URL url, List<FileProcessor> processors) {
		logger.logMessage(LogLevel.INFO, "处理插件jar包中的资源{0}", url);
		FileObject fileObj = VFS.resolveFile(url.toString());
		resolveFileObject(fileObj, processors);
		logger.logMessage(LogLevel.INFO, "处理插件jar包中的资源{0}完毕", url);
	}

	private void resolveFileObject(FileObject file,
			List<FileProcessor> processors) {

		if (file.isFolder()) {
			for (FileObject f : file.getChildren()) {
				resolveFileObject(f, processors);
			}
		} else {
			process(file, processors);
		}
	}

	private void process(FileObject fileObject, List<FileProcessor> processors) {
		if (!fileObject.isExist())
			return;
		for (FileProcessor fileProcessor : processors) {
			if (fileProcessor.isMatch(fileObject)) {
				addFile(fileObject, fileProcessor);
			}
		}

	}

	private void cleanProcessor(List<FileProcessor> processors) {
		for (FileProcessor fileProcessor : processors) {
			fileProcessor.clean();
		}
	}

	private void addFile(FileObject fileObject, FileProcessor fileProcessor) {
		fileProcessor.add(fileObject);
	}
}
